Module update

Module update 

Update command implementations (add, remove, modify, compact)

NOTE: These operations require methods to be implemented in embeddenator-fs component. Currently, they return errors indicating the features are not yet available.

Functions

handle_update_add
handle_update_compact
handle_update_modify
handle_update_remove