Update command implementations (add, remove, modify, compact)
NOTE: These operations require methods to be implemented in embeddenator-fs component. Currently, they return errors indicating the features are not yet available.
Update command implementations (add, remove, modify, compact)
NOTE: These operations require methods to be implemented in embeddenator-fs component. Currently, they return errors indicating the features are not yet available.